@@ -1,4 +1,5 @@
 import os
+
 try:
     from scandir import walk
 except ImportError:
@@ -7,6 +8,7 @@ except ImportError:
 from .compressed_filepath.types import *
 from .compressed_filepath.iteration import IterationSet
 from .compressed_filepath.tokenize import Tokenizer
+from .compressed_filepath._base import filter_string_list
 
 
 def expand_filepath(filepath):
@@ -43,7 +45,7 @@ def walk_dir(directory, recursive=True, include=None, exclude=None):
             item_path = abspath(join(directory, item))
             if not is_dir(item_path):
                 filepaths.append(item_path)
-                
+
         for compressed in compress_filepaths(
             filepaths, include=include, exclude=exclude
         ):
@@ -67,21 +69,23 @@ def get_human_readable(size, base=1024):
     """
 
     if not isinstance(size, (int, float)):
-        raise AssertionError('fs_util.get_human_readable function requires the size argument to be an int or float')
+        raise AssertionError(
+            "fs_util.get_human_readable function requires the size argument to be an int or float"
+        )
 
-    size_types = ['B', 'KB', 'MB', 'GB', 'TB']
+    size_types = ["B", "KB", "MB", "GB", "TB"]
 
     for i, _ in enumerate(sorted(size_types, reverse=True)):
         i = len(size_types) - i
-        if size > base ** i:
-            return '{0:.2f} {1}'.format(size / float(base) ** i, size_types[i])
+        if size > base**i:
+            return "{0:.2f} {1}".format(size / float(base) ** i, size_types[i])
 
-    return '{0:.2f} {1}'.format(float(size), 'B')
+    return "{0:.2f} {1}".format(float(size), "B")
 
 
 def mkdirs(path, mode, owner=-1, group=-1):
-    assert isinstance(owner, int), 'the owner must be an int representing a uid'
-    assert isinstance(group, int), 'the group must be an int representing a gid'
+    assert isinstance(owner, int), "the owner must be an int representing a uid"
+    assert isinstance(group, int), "the group must be an int representing a gid"
     s = path.split(os.sep)
     no_exists = []
     while not os.path.exists(path):
@@ -93,7 +97,7 @@ def mkdirs(path, mode, owner=-1, group=-1):
         try:
             os.mkdir(new_path)
         except OSError as e:
-            if 'errno 17' in str(e).lower():
+            if "errno 17" in str(e).lower():
                 continue
             else:
                 raise
@@ -109,7 +113,7 @@ def find_shared_folder(file_paths):
     :param file_paths: list(str(filepath)s)
     :return: str(filepath)
     """
-    file_paths = sorted(file_paths, key=lambda path: path.count('/'))
+    file_paths = sorted(file_paths, key=lambda path: path.count("/"))
 
     dir_path = os.path.dirname(file_paths[0])
     while True:
